// Copyright (C) 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Copyright 2013 Google Inc. All Rights Reserved.
// Author: ulas@google.com (Ulas Kirazci)
//
// Generated from translit-table.cpp. Maps the first character of
// ascii to possible utf8 variants. Also a set of utf8 characters are
// nullable (e.g., may be skipped in the key). These are listed as
// "[0]".
//
// Then, each mapping can be an exact mapping (a -> à) or must/can
// match a longer prefix in the key (d or dj -> đ). These are encoded
// after the mapping and are called restricts.
//
// Only includes lowercase and isletter characters.

#ifndef ICING_LEGACY_INDEX_ICING_VARIANT_MAP_H_
#define ICING_LEGACY_INDEX_ICING_VARIANT_MAP_H_

const char kVariantMapElts[] =
    "ʰ"             // [0] -> [ʰ] \312\260
    "ʱ"             // [0] -> [ʱ] \312\261
    "ʲ"             // [0] -> [ʲ] \312\262
    "ʳ"             // [0] -> [ʳ] \312\263
    "ʴ"             // [0] -> [ʴ] \312\264
    "ʵ"             // [0] -> [ʵ] \312\265
    "ʶ"             // [0] -> [ʶ] \312\266
    "ʷ"             // [0] -> [ʷ] \312\267
    "ʸ"             // [0] -> [ʸ] \312\270
    "ʹ"             // [0] -> [ʹ] \312\271
    "ʺ"             // [0] -> [ʺ] \312\272
    "ʻ"             // [0] -> [ʻ] \312\273
    "ʼ"             // [0] -> [ʼ] \312\274
    "ʽ"             // [0] -> [ʽ] \312\275
    "ʾ"             // [0] -> [ʾ] \312\276
    "ʿ"             // [0] -> [ʿ] \312\277
    "ˀ"             // [0] -> [ˀ] \313\200
    "ˁ"             // [0] -> [ˁ] \313\201
    "ˆ"             // [0] -> [ˆ] \313\206
    "ˇ"             // [0] -> [ˇ] \313\207
    "ˈ"             // [0] -> [ˈ] \313\210
    "ˉ"             // [0] -> [ˉ] \313\211
    "ˊ"             // [0] -> [ˊ] \313\212
    "ˋ"             // [0] -> [ˋ] \313\213
    "ˌ"             // [0] -> [ˌ] \313\214
    "ˍ"             // [0] -> [ˍ] \313\215
    "ˎ"             // [0] -> [ˎ] \313\216
    "ˏ"             // [0] -> [ˏ] \313\217
    "ː"             // [0] -> [ː] \313\220
    "ˑ"             // [0] -> [ˑ] \313\221
    "ˠ"             // [0] -> [ˠ] \313\240
    "ˡ"             // [0] -> [ˡ] \313\241
    "ˢ"             // [0] -> [ˢ] \313\242
    "ˣ"             // [0] -> [ˣ] \313\243
    "ˤ"             // [0] -> [ˤ] \313\244
    "ˬ"             // [0] -> [ˬ] \313\254
    "ˮ"             // [0] -> [ˮ] \313\256
    "̀"              // [0] -> [̀] \314\200
    "́"              // [0] -> [́] \314\201
    "̂"              // [0] -> [̂] \314\202
    "̃"              // [0] -> [̃] \314\203
    "̄"              // [0] -> [̄] \314\204
    "̅"              // [0] -> [̅] \314\205
    "̆"              // [0] -> [̆] \314\206
    "̇"              // [0] -> [̇] \314\207
    "̈"              // [0] -> [̈] \314\210
    "̉"              // [0] -> [̉] \314\211
    "̊"              // [0] -> [̊] \314\212
    "̋"              // [0] -> [̋] \314\213
    "̌"              // [0] -> [̌] \314\214
    "̍"              // [0] -> [̍] \314\215
    "̎"              // [0] -> [̎] \314\216
    "̏"              // [0] -> [̏] \314\217
    "̐"              // [0] -> [̐] \314\220
    "̑"              // [0] -> [̑] \314\221
    "̒"              // [0] -> [̒] \314\222
    "̓"              // [0] -> [̓] \314\223
    "̔"              // [0] -> [̔] \314\224
    "̕"              // [0] -> [̕] \314\225
    "̖"              // [0] -> [̖] \314\226
    "̗"              // [0] -> [̗] \314\227
    "̘"              // [0] -> [̘] \314\230
    "̙"              // [0] -> [̙] \314\231
    "̚"              // [0] -> [̚] \314\232
    "̛"              // [0] -> [̛] \314\233
    "̜"              // [0] -> [̜] \314\234
    "̝"              // [0] -> [̝] \314\235
    "̞"              // [0] -> [̞] \314\236
    "̟"              // [0] -> [̟] \314\237
    "̠"              // [0] -> [̠] \314\240
    "̡"              // [0] -> [̡] \314\241
    "̢"              // [0] -> [̢] \314\242
    "̣"              // [0] -> [̣] \314\243
    "̤"              // [0] -> [̤] \314\244
    "̥"              // [0] -> [̥] \314\245
    "̦"              // [0] -> [̦] \314\246
    "̧"              // [0] -> [̧] \314\247
    "̨"              // [0] -> [̨] \314\250
    "̩"              // [0] -> [̩] \314\251
    "̪"              // [0] -> [̪] \314\252
    "̫"              // [0] -> [̫] \314\253
    "̬"              // [0] -> [̬] \314\254
    "̭"              // [0] -> [̭] \314\255
    "̮"              // [0] -> [̮] \314\256
    "̯"              // [0] -> [̯] \314\257
    "̰"              // [0] -> [̰] \314\260
    "̱"              // [0] -> [̱] \314\261
    "̲"              // [0] -> [̲] \314\262
    "̳"              // [0] -> [̳] \314\263
    "̴"              // [0] -> [̴] \314\264
    "̵"              // [0] -> [̵] \314\265
    "̶"              // [0] -> [̶] \314\266
    "̷"              // [0] -> [̷] \314\267
    "̸"              // [0] -> [̸] \314\270
    "̹"              // [0] -> [̹] \314\271
    "̺"              // [0] -> [̺] \314\272
    "̻"              // [0] -> [̻] \314\273
    "̼"              // [0] -> [̼] \314\274
    "̽"              // [0] -> [̽] \314\275
    "̾"              // [0] -> [̾] \314\276
    "̿"              // [0] -> [̿] \314\277
    "̀"              // [0] -> [̀] \315\200
    "́"              // [0] -> [́] \315\201
    "͂"              // [0] -> [͂] \315\202
    "̓"              // [0] -> [̓] \315\203
    "̈́"              // [0] -> [̈́] \315\204
    "ͅ"              // [0] -> [ͅ] \315\205
    "͆"              // [0] -> [͆] \315\206
    "͇"              // [0] -> [͇] \315\207
    "͈"              // [0] -> [͈] \315\210
    "͉"              // [0] -> [͉] \315\211
    "͊"              // [0] -> [͊] \315\212
    "͋"              // [0] -> [͋] \315\213
    "͌"              // [0] -> [͌] \315\214
    "͍"              // [0] -> [͍] \315\215
    "͎"              // [0] -> [͎] \315\216
    "͏"            // [0] -> [͏] \315\217
    "͐"              // [0] -> [͐] \315\220
    "͑"              // [0] -> [͑] \315\221
    "͒"              // [0] -> [͒] \315\222
    "͓"              // [0] -> [͓] \315\223
    "͔"              // [0] -> [͔] \315\224
    "͕"              // [0] -> [͕] \315\225
    "͖"              // [0] -> [͖] \315\226
    "͗"              // [0] -> [͗] \315\227
    "͘"              // [0] -> [͘] \315\230
    "͙"              // [0] -> [͙] \315\231
    "͚"              // [0] -> [͚] \315\232
    "͛"              // [0] -> [͛] \315\233
    "͜"              // [0] -> [͜] \315\234
    "͝"              // [0] -> [͝] \315\235
    "͞"              // [0] -> [͞] \315\236
    "͟"              // [0] -> [͟] \315\237
    "͠"              // [0] -> [͠] \315\240
    "͡"              // [0] -> [͡] \315\241
    "͢"              // [0] -> [͢] \315\242
    "ͣ"              // [0] -> [ͣ] \315\243
    "ͤ"              // [0] -> [ͤ] \315\244
    "ͥ"              // [0] -> [ͥ] \315\245
    "ͦ"              // [0] -> [ͦ] \315\246
    "ͧ"              // [0] -> [ͧ] \315\247
    "ͨ"              // [0] -> [ͨ] \315\250
    "ͩ"              // [0] -> [ͩ] \315\251
    "ͪ"              // [0] -> [ͪ] \315\252
    "ͫ"              // [0] -> [ͫ] \315\253
    "ͬ"              // [0] -> [ͬ] \315\254
    "ͭ"              // [0] -> [ͭ] \315\255
    "ͮ"              // [0] -> [ͮ] \315\256
    "ͯ"              // [0] -> [ͯ] \315\257
    "ъ"             // [0] -> [ъ] \321\212
    "ь"             // [0] -> [ь] \321\214
    "֑"              // [0] -> [֑] \326\221
    "֒"              // [0] -> [֒] \326\222
    "֓"              // [0] -> [֓] \326\223
    "֔"              // [0] -> [֔] \326\224
    "֕"              // [0] -> [֕] \326\225
    "֖"              // [0] -> [֖] \326\226
    "֗"              // [0] -> [֗] \326\227
    "֘"              // [0] -> [֘] \326\230
    "֙"              // [0] -> [֙] \326\231
    "֚"              // [0] -> [֚] \326\232
    "֛"              // [0] -> [֛] \326\233
    "֜"              // [0] -> [֜] \326\234
    "֝"              // [0] -> [֝] \326\235
    "֞"              // [0] -> [֞] \326\236
    "֟"              // [0] -> [֟] \326\237
    "֠"              // [0] -> [֠] \326\240
    "֡"              // [0] -> [֡] \326\241
    "֢"              // [0] -> [֢] \326\242
    "֣"              // [0] -> [֣] \326\243
    "֤"              // [0] -> [֤] \326\244
    "֥"              // [0] -> [֥] \326\245
    "֦"              // [0] -> [֦] \326\246
    "֧"              // [0] -> [֧] \326\247
    "֨"              // [0] -> [֨] \326\250
    "֩"              // [0] -> [֩] \326\251
    "֪"              // [0] -> [֪] \326\252
    "֫"              // [0] -> [֫] \326\253
    "֬"              // [0] -> [֬] \326\254
    "֭"              // [0] -> [֭] \326\255
    "֮"              // [0] -> [֮] \326\256
    "֯"              // [0] -> [֯] \326\257
    "ְ"              // [0] -> [ְ] \326\260
    "ֱ"              // [0] -> [ֱ] \326\261
    "ֲ"              // [0] -> [ֲ] \326\262
    "ֳ"              // [0] -> [ֳ] \326\263
    "ִ"              // [0] -> [ִ] \326\264
    "ֵ"              // [0] -> [ֵ] \326\265
    "ֶ"              // [0] -> [ֶ] \326\266
    "ַ"              // [0] -> [ַ] \326\267
    "ָ"              // [0] -> [ָ] \326\270
    "ֹ"              // [0] -> [ֹ] \326\271
    "ֺ"              // [0] -> [ֺ] \326\272
    "ֻ"              // [0] -> [ֻ] \326\273
    "ּ"              // [0] -> [ּ] \326\274
    "ֽ"              // [0] -> [ֽ] \326\275
    "ֿ"              // [0] -> [ֿ] \326\277
    "ׁ"              // [0] -> [ׁ] \327\201
    "ׂ"              // [0] -> [ׂ] \327\202
    "ׄ"              // [0] -> [ׄ] \327\204
    "ׅ"              // [0] -> [ׅ] \327\205
    "ׇ"              // [0] -> [ׇ] \327\207
    "ؐ"              // [0] -> [ؐ] \330\220
    "ؑ"              // [0] -> [ؑ] \330\221
    "ؒ"              // [0] -> [ؒ] \330\222
    "ؓ"              // [0] -> [ؓ] \330\223
    "ؔ"              // [0] -> [ؔ] \330\224
    "ؕ"              // [0] -> [ؕ] \330\225
    "ً"              // [0] -> [ً] \331\213
    "ٌ"              // [0] -> [ٌ] \331\214
    "ٍ"              // [0] -> [ٍ] \331\215
    "َ"              // [0] -> [َ] \331\216
    "ُ"              // [0] -> [ُ] \331\217
    "ِ"              // [0] -> [ِ] \331\220
    "ّ"              // [0] -> [ّ] \331\221
    "ْ"              // [0] -> [ْ] \331\222
    "ٓ"              // [0] -> [ٓ] \331\223
    "ٔ"              // [0] -> [ٔ] \331\224
    "ٕ"              // [0] -> [ٕ] \331\225
    "ٖ"              // [0] -> [ٖ] \331\226
    "ٗ"              // [0] -> [ٗ] \331\227
    "٘"              // [0] -> [٘] \331\230
    "ٙ"              // [0] -> [ٙ] \331\231
    "ٚ"              // [0] -> [ٚ] \331\232
    "ٛ"              // [0] -> [ٛ] \331\233
    "ٜ"              // [0] -> [ٜ] \331\234
    "ٝ"              // [0] -> [ٝ] \331\235
    "ٞ"              // [0] -> [ٞ] \331\236
    "ٰ"              // [0] -> [ٰ] \331\260
    "ۖ"              // [0] -> [ۖ] \333\226
    "ۗ"              // [0] -> [ۗ] \333\227
    "ۘ"              // [0] -> [ۘ] \333\230
    "ۙ"              // [0] -> [ۙ] \333\231
    "ۚ"              // [0] -> [ۚ] \333\232
    "ۛ"              // [0] -> [ۛ] \333\233
    "ۜ"              // [0] -> [ۜ] \333\234
    "۟"              // [0] -> [۟] \333\237
    "۠"              // [0] -> [۠] \333\240
    "ۡ"              // [0] -> [ۡ] \333\241
    "ۢ"              // [0] -> [ۢ] \333\242
    "ۣ"              // [0] -> [ۣ] \333\243
    "ۤ"              // [0] -> [ۤ] \333\244
    "ۧ"              // [0] -> [ۧ] \333\247
    "ۨ"              // [0] -> [ۨ] \333\250
    "۪"              // [0] -> [۪] \333\252
    "۫"              // [0] -> [۫] \333\253
    "۬"              // [0] -> [۬] \333\254
    "ۭ"              // [0] -> [ۭ] \333\255
    "ം"             // [0] -> [ം] \340\264\202
    "ഃ"             // [0] -> [ഃ] \340\264\203
    "്"              // [0] -> [്] \340\265\215
    "่"              // [0] -> [่] \340\271\210
    "้"              // [0] -> [้] \340\271\211
    "๊"              // [0] -> [๊] \340\271\212
    "๋"              // [0] -> [๋] \340\271\213
    "່"              // [0] -> [່] \340\273\210
    "້"              // [0] -> [້] \340\273\211
    "໊"              // [0] -> [໊] \340\273\212
    "໋"              // [0] -> [໋] \340\273\213
    "‌"           // [0] -> [‌] \342\200\214
    "‍"           // [0] -> [‍] \342\200\215
    "\0"            // [0] end
    "à"             // [a] -> [à] \303\240
    "á"             // [a] -> [á] \303\241
    "â"             // [a] -> [â] \303\242
    "ã"             // [a] -> [ã] \303\243
    "äa\0ae\0"      // [a] -> [ä] \303\244
    "åa\0aa\0"      // [a] -> [å] \303\245
    "æae\0"         // [a] -> [æ] \303\246
    "ā"             // [a] -> [ā] \304\201
    "ă"             // [a] -> [ă] \304\203
    "ą"             // [a] -> [ą] \304\205
    "ά"             // [a] -> [ά] \316\254
    "α"             // [a] -> [α] \316\261
    "а"             // [a] -> [а] \320\260
    "ъ"             // [a] -> [ъ] \321\212
    "ա"             // [a] -> [ա] \325\241
    "ა"             // [a] -> [ა] \341\203\220
    "ḁ"             // [a] -> [ḁ] \341\270\201
    "ẚ"             // [a] -> [ẚ] \341\272\232
    "ạ"             // [a] -> [ạ] \341\272\241
    "ả"             // [a] -> [ả] \341\272\243
    "ấ"             // [a] -> [ấ] \341\272\245
    "ầ"             // [a] -> [ầ] \341\272\247
    "ẩ"             // [a] -> [ẩ] \341\272\251
    "ẫ"             // [a] -> [ẫ] \341\272\253
    "ậ"             // [a] -> [ậ] \341\272\255
    "ắ"             // [a] -> [ắ] \341\272\257
    "ằ"             // [a] -> [ằ] \341\272\261
    "ẳ"             // [a] -> [ẳ] \341\272\263
    "ẵ"             // [a] -> [ẵ] \341\272\265
    "ặ"             // [a] -> [ặ] \341\272\267
    "ἀ"             // [a] -> [ἀ] \341\274\200
    "ἁ"             // [a] -> [ἁ] \341\274\201
    "ἂ"             // [a] -> [ἂ] \341\274\202
    "ἃ"             // [a] -> [ἃ] \341\274\203
    "ἄ"             // [a] -> [ἄ] \341\274\204
    "ἅ"             // [a] -> [ἅ] \341\274\205
    "ἆ"             // [a] -> [ἆ] \341\274\206
    "ἇ"             // [a] -> [ἇ] \341\274\207
    "\0"            // [a] end
    "б"             // [b] -> [б] \320\261
    "բ"             // [b] -> [բ] \325\242
    "ბ"             // [b] -> [ბ] \341\203\221
    "ḃ"             // [b] -> [ḃ] \341\270\203
    "ḅ"             // [b] -> [ḅ] \341\270\205
    "ḇ"             // [b] -> [ḇ] \341\270\207
    "\0"            // [b] end
    "ç"             // [c] -> [ç] \303\247
    "ć"             // [c] -> [ć] \304\207
    "ĉ"             // [c] -> [ĉ] \304\211
    "ċ"             // [c] -> [ċ] \304\213
    "č"             // [c] -> [č] \304\215
    "ц"             // [c] -> [ц] \321\206
    "чc\0ch\0"      // [c] -> [ч] \321\207
    "ћ"             // [c] -> [ћ] \321\233
    "ҹ"             // [c] -> [ҹ] \322\271
    "չch\0"         // [c] -> [չ] \325\271
    "ჩch\0"         // [c] -> [ჩ] \341\203\251
    "ჭch\0"         // [c] -> [ჭ] \341\203\255
    "ḉ"             // [c] -> [ḉ] \341\270\211
    "\0"            // [c] end
    "ð"             // [d] -> [ð] \303\260
    "ď"             // [d] -> [ď] \304\217
    "đd\0dj\0"      // [d] -> [đ] \304\221
    "δ"             // [d] -> [δ] \316\264
    "д"             // [d] -> [д] \320\264
    "ђdj\0"         // [d] -> [ђ] \321\222
    "ѕdz\0"         // [d] -> [ѕ] \321\225
    "џdj\0dz\0"     // [d] -> [џ] \321\237
    "դ"             // [d] -> [դ] \325\244
    "დ"             // [d] -> [დ] \341\203\223
    "ძdz\0"         // [d] -> [ძ] \341\203\253
    "ḋ"             // [d] -> [ḋ] \341\270\213
    "ḍ"             // [d] -> [ḍ] \341\270\215
    "ḏ"             // [d] -> [ḏ] \341\270\217
    "ḑ"             // [d] -> [ḑ] \341\270\221
    "ḓ"             // [d] -> [ḓ] \341\270\223
    "\0"            // [d] end
    "è"             // [e] -> [è] \303\250
    "é"             // [e] -> [é] \303\251
    "ê"             // [e] -> [ê] \303\252
    "ë"             // [e] -> [ë] \303\253
    "ē"             // [e] -> [ē] \304\223
    "ĕ"             // [e] -> [ĕ] \304\225
    "ė"             // [e] -> [ė] \304\227
    "ę"             // [e] -> [ę] \304\231
    "ě"             // [e] -> [ě] \304\233
    "έ"             // [e] -> [έ] \316\255
    "ε"             // [e] -> [ε] \316\265
    "ϵ"             // [e] -> [ϵ] \317\265
    "е"             // [e] -> [е] \320\265
    "э"             // [e] -> [э] \321\215
    "ѐ"             // [e] -> [ѐ] \321\220
    "ё"             // [e] -> [ё] \321\221
    "є"             // [e] -> [є] \321\224
    "ә"             // [e] -> [ә] \323\231
    "ե"             // [e] -> [ե] \325\245
    "է"             // [e] -> [է] \325\247
    "ըeh\0"         // [e] -> [ը] \325\250
    "ևev\0"         // [e] -> [և] \326\207
    "ე"             // [e] -> [ე] \341\203\224
    "ვ"             // [e] -> [ვ] \341\203\225
    "ḕ"             // [e] -> [ḕ] \341\270\225
    "ḗ"             // [e] -> [ḗ] \341\270\227
    "ḙ"             // [e] -> [ḙ] \341\270\231
    "ḛ"             // [e] -> [ḛ] \341\270\233
    "ḝ"             // [e] -> [ḝ] \341\270\235
    "ẹ"             // [e] -> [ẹ] \341\272\271
    "ẻ"             // [e] -> [ẻ] \341\272\273
    "ẽ"             // [e] -> [ẽ] \341\272\275
    "ế"             // [e] -> [ế] \341\272\277
    "ề"             // [e] -> [ề] \341\273\201
    "ể"             // [e] -> [ể] \341\273\203
    "ễ"             // [e] -> [ễ] \341\273\205
    "ệ"             // [e] -> [ệ] \341\273\207
    "ἐ"             // [e] -> [ἐ] \341\274\220
    "ἑ"             // [e] -> [ἑ] \341\274\221
    "ἒ"             // [e] -> [ἒ] \341\274\222
    "ἓ"             // [e] -> [ἓ] \341\274\223
    "ἔ"             // [e] -> [ἔ] \341\274\224
    "ἕ"             // [e] -> [ἕ] \341\274\225
    "\0"            // [e] end
    "φ"             // [f] -> [φ] \317\206
    "ϕ"             // [f] -> [ϕ] \317\225
    "ф"             // [f] -> [ф] \321\204
    "ֆ"             // [f] -> [ֆ] \326\206
    "ḟ"             // [f] -> [ḟ] \341\270\237
    "ẛ"             // [f] -> [ẛ] \341\272\233
    "\0"            // [f] end
    "ĝ"             // [g] -> [ĝ] \304\235
    "ğ"             // [g] -> [ğ] \304\237
    "ġ"             // [g] -> [ġ] \304\241
    "ģ"             // [g] -> [ģ] \304\243
    "γ"             // [g] -> [γ] \316\263
    "г"             // [g] -> [г] \320\263
    "ѓ"             // [g] -> [ѓ] \321\223
    "ґ"             // [g] -> [ґ] \322\221
    "ғ"             // [g] -> [ғ] \322\223
    "ҝ"             // [g] -> [ҝ] \322\235
    "գ"             // [g] -> [գ] \325\243
    "ղgh\0"         // [g] -> [ղ] \325\262
    "ջ"             // [g] -> [ջ] \325\273
    "გ"             // [g] -> [გ] \341\203\222
    "ღgh\0"         // [g] -> [ღ] \341\203\246
    "ḡ"             // [g] -> [ḡ] \341\270\241
    "\0"            // [g] end
    "ĥ"             // [h] -> [ĥ] \304\245
    "ħ"             // [h] -> [ħ] \304\247
    "х"             // [h] -> [х] \321\205
    "һ"             // [h] -> [һ] \322\273
    "հ"             // [h] -> [հ] \325\260
    "ჰ"             // [h] -> [ჰ] \341\203\260
    "ḣ"             // [h] -> [ḣ] \341\270\243
    "ḥ"             // [h] -> [ḥ] \341\270\245
    "ḧ"             // [h] -> [ḧ] \341\270\247
    "ḩ"             // [h] -> [ḩ] \341\270\251
    "ḫ"             // [h] -> [ḫ] \341\270\253
    "ẖ"             // [h] -> [ẖ] \341\272\226
    "\0"            // [h] end
    "ì"             // [i] -> [ì] \303\254
    "í"             // [i] -> [í] \303\255
    "î"             // [i] -> [î] \303\256
    "ï"             // [i] -> [ï] \303\257
    "ý"             // [i] -> [ý] \303\275
    "ĩ"             // [i] -> [ĩ] \304\251
    "ī"             // [i] -> [ī] \304\253
    "ĭ"             // [i] -> [ĭ] \304\255
    "į"             // [i] -> [į] \304\257
    "ı"             // [i] -> [ı] \304\261
    "ΐ"             // [i] -> [ΐ] \316\220
    "ή"             // [i] -> [ή] \316\256
    "ί"             // [i] -> [ί] \316\257
    "ΰ"             // [i] -> [ΰ] \316\260
    "η"             // [i] -> [η] \316\267
    "ι"             // [i] -> [ι] \316\271
    "υ"             // [i] -> [υ] \317\205
    "ϊ"             // [i] -> [ϊ] \317\212
    "ϋ"             // [i] -> [ϋ] \317\213
    "ύ"             // [i] -> [ύ] \317\215
    "и"             // [i] -> [и] \320\270
    "й"             // [i] -> [й] \320\271
    "і"             // [i] -> [і] \321\226
    "ї"             // [i] -> [ї] \321\227
    "ի"             // [i] -> [ի] \325\253
    "ი"             // [i] -> [ი] \341\203\230
    "ḭ"             // [i] -> [ḭ] \341\270\255
    "ḯ"             // [i] -> [ḯ] \341\270\257
    "ỉ"             // [i] -> [ỉ] \341\273\211
    "ị"             // [i] -> [ị] \341\273\213
    "ἠ"             // [i] -> [ἠ] \341\274\240
    "ἡ"             // [i] -> [ἡ] \341\274\241
    "ἢ"             // [i] -> [ἢ] \341\274\242
    "ἣ"             // [i] -> [ἣ] \341\274\243
    "ἤ"             // [i] -> [ἤ] \341\274\244
    "ἥ"             // [i] -> [ἥ] \341\274\245
    "ἦ"             // [i] -> [ἦ] \341\274\246
    "ἧ"             // [i] -> [ἧ] \341\274\247
    "ἰ"             // [i] -> [ἰ] \341\274\260
    "ἱ"             // [i] -> [ἱ] \341\274\261
    "ἲ"             // [i] -> [ἲ] \341\274\262
    "ἳ"             // [i] -> [ἳ] \341\274\263
    "ἴ"             // [i] -> [ἴ] \341\274\264
    "ἵ"             // [i] -> [ἵ] \341\274\265
    "ἶ"             // [i] -> [ἶ] \341\274\266
    "ἷ"             // [i] -> [ἷ] \341\274\267
    "ὐ"             // [i] -> [ὐ] \341\275\220
    "ὑ"             // [i] -> [ὑ] \341\275\221
    "ὒ"             // [i] -> [ὒ] \341\275\222
    "ὓ"             // [i] -> [ὓ] \341\275\223
    "ὔ"             // [i] -> [ὔ] \341\275\224
    "ὕ"             // [i] -> [ὕ] \341\275\225
    "ὖ"             // [i] -> [ὖ] \341\275\226
    "ὗ"             // [i] -> [ὗ] \341\275\227
    "\0"            // [i] end
    "ĵ"             // [j] -> [ĵ] \304\265
    "ж"             // [j] -> [ж] \320\266
    "ј"             // [j] -> [ј] \321\230
    "ժ"             // [j] -> [ժ] \325\252
    "ճ"             // [j] -> [ճ] \325\263
    "ჯ"             // [j] -> [ჯ] \341\203\257
    "\0"            // [j] end
    "ķ"             // [k] -> [ķ] \304\267
    "κ"             // [k] -> [κ] \316\272
    "ϰ"             // [k] -> [ϰ] \317\260
    "к"             // [k] -> [к] \320\272
    "хkh\0"         // [k] -> [х] \321\205
    "ќ"             // [k] -> [ќ] \321\234
    "կ"             // [k] -> [կ] \325\257
    "ք"             // [k] -> [ք] \326\204
    "კ"             // [k] -> [კ] \341\203\231
    "ქkh\0"         // [k] -> [ქ] \341\203\245
    "ḱ"             // [k] -> [ḱ] \341\270\261
    "ḳ"             // [k] -> [ḳ] \341\270\263
    "ḵ"             // [k] -> [ḵ] \341\270\265
    "\0"            // [k] end
    "ĺ"             // [l] -> [ĺ] \304\272
    "ļ"             // [l] -> [ļ] \304\274
    "ľ"             // [l] -> [ľ] \304\276
    "ŀ"             // [l] -> [ŀ] \305\200
    "ł"             // [l] -> [ł] \305\202
    "λ"             // [l] -> [λ] \316\273
    "л"             // [l] -> [л] \320\273
    "љlj\0"         // [l] -> [љ] \321\231
    "լ"             // [l] -> [լ] \325\254
    "ლ"             // [l] -> [ლ] \341\203\232
    "ḷ"             // [l] -> [ḷ] \341\270\267
    "ḹ"             // [l] -> [ḹ] \341\270\271
    "ḻ"             // [l] -> [ḻ] \341\270\273
    "ḽ"             // [l] -> [ḽ] \341\270\275
    "\0"            // [l] end
    "μ"             // [m] -> [μ] \316\274
    "м"             // [m] -> [м] \320\274
    "մ"             // [m] -> [մ] \325\264
    "მ"             // [m] -> [მ] \341\203\233
    "ḿ"             // [m] -> [ḿ] \341\270\277
    "ṁ"             // [m] -> [ṁ] \341\271\201
    "ṃ"             // [m] -> [ṃ] \341\271\203
    "\0"            // [m] end
    "ñ"             // [n] -> [ñ] \303\261
    "ń"             // [n] -> [ń] \305\204
    "ņ"             // [n] -> [ņ] \305\206
    "ň"             // [n] -> [ň] \305\210
    "ŋ"             // [n] -> [ŋ] \305\213
    "ν"             // [n] -> [ν] \316\275
    "н"             // [n] -> [н] \320\275
    "њnj\0"         // [n] -> [њ] \321\232
    "ն"             // [n] -> [ն] \325\266
    "ნ"             // [n] -> [ნ] \341\203\234
    "ṅ"             // [n] -> [ṅ] \341\271\205
    "ṇ"             // [n] -> [ṇ] \341\271\207
    "ṉ"             // [n] -> [ṉ] \341\271\211
    "ṋ"             // [n] -> [ṋ] \341\271\213
    "\0"            // [n] end
    "ò"             // [o] -> [ò] \303\262
    "ó"             // [o] -> [ó] \303\263
    "ô"             // [o] -> [ô] \303\264
    "õ"             // [o] -> [õ] \303\265
    "öo\0oe\0"      // [o] -> [ö] \303\266
    "øo\0oe\0"      // [o] -> [ø] \303\270
    "ō"             // [o] -> [ō] \305\215
    "ŏ"             // [o] -> [ŏ] \305\217
    "ő"             // [o] -> [ő] \305\221
    "œoe\0"         // [o] -> [œ] \305\223
    "ơ"             // [o] -> [ơ] \306\241
    "ο"             // [o] -> [ο] \316\277
    "ω"             // [o] -> [ω] \317\211
    "ό"             // [o] -> [ό] \317\214
    "ώ"             // [o] -> [ώ] \317\216
    "о"             // [o] -> [о] \320\276
    "ө"             // [o] -> [ө] \323\251
    "ո"             // [o] -> [ո] \325\270
    "օ"             // [o] -> [օ] \326\205
    "ო"             // [o] -> [ო] \341\203\235
    "ṍ"             // [o] -> [ṍ] \341\271\215
    "ṏ"             // [o] -> [ṏ] \341\271\217
    "ṑ"             // [o] -> [ṑ] \341\271\221
    "ṓ"             // [o] -> [ṓ] \341\271\223
    "ọ"             // [o] -> [ọ] \341\273\215
    "ỏ"             // [o] -> [ỏ] \341\273\217
    "ố"             // [o] -> [ố] \341\273\221
    "ồ"             // [o] -> [ồ] \341\273\223
    "ổ"             // [o] -> [ổ] \341\273\225
    "ỗ"             // [o] -> [ỗ] \341\273\227
    "ộ"             // [o] -> [ộ] \341\273\231
    "ớ"             // [o] -> [ớ] \341\273\233
    "ờ"             // [o] -> [ờ] \341\273\235
    "ở"             // [o] -> [ở] \341\273\237
    "ỡ"             // [o] -> [ỡ] \341\273\241
    "ợ"             // [o] -> [ợ] \341\273\243
    "ὀ"             // [o] -> [ὀ] \341\275\200
    "ὁ"             // [o] -> [ὁ] \341\275\201
    "ὂ"             // [o] -> [ὂ] \341\275\202
    "ὃ"             // [o] -> [ὃ] \341\275\203
    "ὄ"             // [o] -> [ὄ] \341\275\204
    "ὅ"             // [o] -> [ὅ] \341\275\205
    "ὠ"             // [o] -> [ὠ] \341\275\240
    "ὡ"             // [o] -> [ὡ] \341\275\241
    "ὢ"             // [o] -> [ὢ] \341\275\242
    "\0"            // [o] end
    "π"             // [p] -> [π] \317\200
    "ψps\0"         // [p] -> [ψ] \317\210
    "ϖ"             // [p] -> [ϖ] \317\226
    "п"             // [p] -> [п] \320\277
    "պ"             // [p] -> [պ] \325\272
    "փ"             // [p] -> [փ] \326\203
    "პ"             // [p] -> [პ] \341\203\236
    "ფph\0"         // [p] -> [ფ] \341\203\244
    "ṕ"             // [p] -> [ṕ] \341\271\225
    "ṗ"             // [p] -> [ṗ] \341\271\227
    "\0"            // [p] end
    "г"             // [q] -> [г] \320\263
    "ყ"             // [q] -> [ყ] \341\203\247
    "\0"            // [q] end
    "ŕ"             // [r] -> [ŕ] \305\225
    "ŗ"             // [r] -> [ŗ] \305\227
    "ř"             // [r] -> [ř] \305\231
    "ρ"             // [r] -> [ρ] \317\201
    "ϱ"             // [r] -> [ϱ] \317\261
    "р"             // [r] -> [р] \321\200
    "ռ"             // [r] -> [ռ] \325\274
    "ր"             // [r] -> [ր] \326\200
    "რ"             // [r] -> [რ] \341\203\240
    "ṙ"             // [r] -> [ṙ] \341\271\231
    "ṛ"             // [r] -> [ṛ] \341\271\233
    "ṝ"             // [r] -> [ṝ] \341\271\235
    "ṟ"             // [r] -> [ṟ] \341\271\237
    "\0"            // [r] end
    "ßss\0"         // [s] -> [ß] \303\237
    "ś"             // [s] -> [ś] \305\233
    "ŝ"             // [s] -> [ŝ] \305\235
    "ş"             // [s] -> [ş] \305\237
    "š"             // [s] -> [š] \305\241
    "ș"             // [s] -> [ș] \310\231
    "ς"             // [s] -> [ς] \317\202
    "σ"             // [s] -> [σ] \317\203
    "ϲ"             // [s] -> [ϲ] \317\262
    "с"             // [s] -> [с] \321\201
    "шs\0sh\0"      // [s] -> [ш] \321\210
    "щshch\0sht\0"  // [s] -> [щ] \321\211
    "շsh\0"         // [s] -> [շ] \325\267
    "ս"             // [s] -> [ս] \325\275
    "ს"             // [s] -> [ს] \341\203\241
    "შsh\0"         // [s] -> [შ] \341\203\250
    "ṡ"             // [s] -> [ṡ] \341\271\241
    "ṣ"             // [s] -> [ṣ] \341\271\243
    "ṥ"             // [s] -> [ṥ] \341\271\245
    "ṧ"             // [s] -> [ṧ] \341\271\247
    "ṩ"             // [s] -> [ṩ] \341\271\251
    "\0"            // [s] end
    "þth\0"         // [t] -> [þ] \303\276
    "ţ"             // [t] -> [ţ] \305\243
    "ť"             // [t] -> [ť] \305\245
    "ŧ"             // [t] -> [ŧ] \305\247
    "ț"             // [t] -> [ț] \310\233
    "θth\0"         // [t] -> [θ] \316\270
    "τ"             // [t] -> [τ] \317\204
    "ϑth\0"         // [t] -> [ϑ] \317\221
    "т"             // [t] -> [т] \321\202
    "цts\0"         // [t] -> [ц] \321\206
    "թ"             // [t] -> [թ] \325\251
    "ծts\0"         // [t] -> [ծ] \325\256
    "տ"             // [t] -> [տ] \325\277
    "ցts\0"         // [t] -> [ց] \326\201
    "თ"             // [t] -> [თ] \341\203\227
    "ტ"             // [t] -> [ტ] \341\203\242
    "ცts\0"         // [t] -> [ც] \341\203\252
    "წts\0"         // [t] -> [წ] \341\203\254
    "ṫ"             // [t] -> [ṫ] \341\271\253
    "ṭ"             // [t] -> [ṭ] \341\271\255
    "ṯ"             // [t] -> [ṯ] \341\271\257
    "ṱ"             // [t] -> [ṱ] \341\271\261
    "ẗ"             // [t] -> [ẗ] \341\272\227
    "\0"            // [t] end
    "ù"             // [u] -> [ù] \303\271
    "ú"             // [u] -> [ú] \303\272
    "û"             // [u] -> [û] \303\273
    "üu\0ue\0"      // [u] -> [ü] \303\274
    "ũ"             // [u] -> [ũ] \305\251
    "ū"             // [u] -> [ū] \305\253
    "ŭ"             // [u] -> [ŭ] \305\255
    "ů"             // [u] -> [ů] \305\257
    "ű"             // [u] -> [ű] \305\261
    "ų"             // [u] -> [ų] \305\263
    "ư"             // [u] -> [ư] \306\260
    "у"             // [u] -> [у] \321\203
    "ў"             // [u] -> [ў] \321\236
    "ү"             // [u] -> [ү] \322\257
    "უ"             // [u] -> [უ] \341\203\243
    "ṳ"             // [u] -> [ṳ] \341\271\263
    "ṵ"             // [u] -> [ṵ] \341\271\265
    "ṷ"             // [u] -> [ṷ] \341\271\267
    "ṹ"             // [u] -> [ṹ] \341\271\271
    "ṻ"             // [u] -> [ṻ] \341\271\273
    "ụ"             // [u] -> [ụ] \341\273\245
    "ủ"             // [u] -> [ủ] \341\273\247
    "ứ"             // [u] -> [ứ] \341\273\251
    "ừ"             // [u] -> [ừ] \341\273\253
    "ử"             // [u] -> [ử] \341\273\255
    "ữ"             // [u] -> [ữ] \341\273\257
    "ự"             // [u] -> [ự] \341\273\261
    "\0"            // [u] end
    "β"             // [v] -> [β] \316\262
    "ϐ"             // [v] -> [ϐ] \317\220
    "в"             // [v] -> [в] \320\262
    "վ"             // [v] -> [վ] \325\276
    "ւ"             // [v] -> [ւ] \326\202
    "ṽ"             // [v] -> [ṽ] \341\271\275
    "ṿ"             // [v] -> [ṿ] \341\271\277
    "\0"            // [v] end
    "ŵ"             // [w] -> [ŵ] \305\265
    "ẁ"             // [w] -> [ẁ] \341\272\201
    "ẃ"             // [w] -> [ẃ] \341\272\203
    "ẅ"             // [w] -> [ẅ] \341\272\205
    "ẇ"             // [w] -> [ẇ] \341\272\207
    "ẉ"             // [w] -> [ẉ] \341\272\211
    "ẘ"             // [w] -> [ẘ] \341\272\230
    "\0"            // [w] end
    "ξ"             // [x] -> [ξ] \316\276
    "χ"             // [x] -> [χ] \317\207
    "х"             // [x] -> [х] \321\205
    "խ"             // [x] -> [խ] \325\255
    "ხ"             // [x] -> [ხ] \341\203\256
    "ẋ"             // [x] -> [ẋ] \341\272\213
    "ẍ"             // [x] -> [ẍ] \341\272\215
    "\0"            // [x] end
    "ý"             // [y] -> [ý] \303\275
    "ÿ"             // [y] -> [ÿ] \303\277
    "ŷ"             // [y] -> [ŷ] \305\267
    "й"             // [y] -> [й] \320\271
    "ы"             // [y] -> [ы] \321\213
    "ь"             // [y] -> [ь] \321\214
    "юyu\0"         // [y] -> [ю] \321\216
    "яya\0"         // [y] -> [я] \321\217
    "ј"             // [y] -> [ј] \321\230
    "յ"             // [y] -> [յ] \325\265
    "ẏ"             // [y] -> [ẏ] \341\272\217
    "ẙ"             // [y] -> [ẙ] \341\272\231
    "ỳ"             // [y] -> [ỳ] \341\273\263
    "ỵ"             // [y] -> [ỵ] \341\273\265
    "ỷ"             // [y] -> [ỷ] \341\273\267
    "ỹ"             // [y] -> [ỹ] \341\273\271
    "\0"            // [y] end
    "ź"             // [z] -> [ź] \305\272
    "ż"             // [z] -> [ż] \305\274
    "ž"             // [z] -> [ž] \305\276
    "ƶ"             // [z] -> [ƶ] \306\266
    "ζ"             // [z] -> [ζ] \316\266
    "жz\0zh\0"      // [z] -> [ж] \320\266
    "з"             // [z] -> [з] \320\267
    "զ"             // [z] -> [զ] \325\246
    "ձ"             // [z] -> [ձ] \325\261
    "ზ"             // [z] -> [ზ] \341\203\226
    "ჟzh\0"         // [z] -> [ჟ] \341\203\237
    "ẑ"             // [z] -> [ẑ] \341\272\221
    "ẓ"             // [z] -> [ẓ] \341\272\223
    "ẕ"             // [z] -> [ẕ] \341\272\225
    "\0"            // [z] end
    ;

// Currently only lowercase ascii characters are mapped from. These
// are indices from the first ascii character in the key into the
// kVariantMapElts string above.
const int kVariantMapIndex[] = {
    536,   // a
    649,   // b
    666,   // c
    710,   // d
    770,   // e
    884,   // f
    899,   // g
    941,   // h
    973,   // i
    1111,  // j
    1125,  // k
    1163,  // l
    1200,  // m
    1219,  // n
    1256,  // o
    1386,  // p
    1417,  // q
    1423,  // r
    1455,  // s
    1528,  // t
    1608,  // u
    1681,  // v
    1698,  // w
    1719,  // x
    1737,  // y
    1782,  // z
};

#endif  // ICING_LEGACY_INDEX_ICING_VARIANT_MAP_H_
